/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.spring.boot.autoconfigure.properties;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class SeataPropertiesTest {

    @Test
    public void testSeataProperties() {
        SeataProperties seataProperties = new SeataProperties();
        seataProperties.setEnabled(true);
        Assertions.assertTrue(seataProperties.isEnabled());

        seataProperties.setApplicationId("applicationId");
        Assertions.assertEquals("applicationId", seataProperties.getApplicationId());

        seataProperties.setTxServiceGroup("group");
        Assertions.assertEquals("group", seataProperties.getTxServiceGroup());

        seataProperties.setEnableAutoDataSourceProxy(true);
        Assertions.assertTrue(seataProperties.isEnableAutoDataSourceProxy());

        seataProperties.setDataSourceProxyMode("AT");
        Assertions.assertEquals("AT", seataProperties.getDataSourceProxyMode());

        seataProperties.setUseJdkProxy(true);
        Assertions.assertTrue(seataProperties.isUseJdkProxy());

        String[] excludesForAutoProxying = new String[]{"test"};
        seataProperties.setExcludesForAutoProxying(excludesForAutoProxying);
        Assertions.assertEquals(excludesForAutoProxying, seataProperties.getExcludesForAutoProxying());

        String[] scanPackages = new String[]{"com"};
        seataProperties.setScanPackages(scanPackages);
        Assertions.assertEquals(scanPackages, seataProperties.getScanPackages());

        String[] excludesForScanning = new String[]{"com"};
        seataProperties.setExcludesForScanning(excludesForScanning);
        Assertions.assertEquals(excludesForScanning, seataProperties.getExcludesForScanning());

        seataProperties.setAccessKey("key");
        Assertions.assertEquals("key", seataProperties.getAccessKey());

        seataProperties.setSecretKey("secret");
        Assertions.assertEquals("secret", seataProperties.getSecretKey());
    }
}
